@@ -143,8 +143,11 @@ class pltstyle(styleapplicator):
     def __init__(self, **kwargs):
         super().__init__()
         total_items = plt_style(**kwargs)
-        self.kwargs = {pltstyle.key_fix(key):value for key,value in total_items.items() if not key.startswith('subplot')}
-        self.subplot_kwargs = {pltstyle.key_fix(key):value for key,value in total_items.items() if key.startswith('subplot')}
+        self.kwargs = {pltstyle.key_fix(key):value for key,value in total_items.items() if not key.startswith('subplot') and key != 'majorplotkey'}
+        self.subplot_kwargs = {pltstyle.key_fix(key):value for key,value in total_items.items() if key.startswith('subplot') and key != 'majorplotkey'}
+        self.majorplotkey = []
+        if "majorplotkey" in total_items:
+            self.majorplotkey = total_items['majorplotkey']
         self.set_env()
     def __enter__(self):return self.from_env()
     def __exit__(self,*args, **kwargs):self.set_env();pass
@@ -152,8 +155,9 @@ class pltstyle(styleapplicator):
     def key_fix(string):return string.replace('_','.')
     def __call__(self, some_figure_obj):
         #https://plotly.com/python/subplots/
+        key_filter_lambda = lambda x:True if self.majorplotkey == [] else lambda x:x in self.majorplotkey
         some_figure_obj.update(
-            **self.kwargs
+            **self.of(use_main_plot=True, key_filter=key_filter_lambda)
         )
 
         #Changing some per-plot settings since they're traces & annotations
@@ -192,22 +196,27 @@ class pltstyle(styleapplicator):
             del self.kwargs[key]
         elif key in self.subplot_kwargs:
             del self.subplot_kwargs[key]
-    @property
-    def total_items(self):
-        return {
-            **self.kwargs,
-            **self.subplot_kwargs,
-        }
-    def __iter__(self):return iter(self.total_items.values())
-    def __reversed__(self):return reversed(self.total_items.values())
-    def __contains__(self, item):return item in self.total_items.keys()
-    def items(self, key_filter=lambda x:True):return [(x, y) for x,y in self.total_items.items() if key_filter(x)]
-    def keys(self, key_filter=lambda x:True):return [x for x in self.total_items.keys() if key_filter(x)]
-    def values(self, key_filter=lambda x:True):return [self[x] for x in self.total_items.keys() if key_filter(x)]
+    def __iter__(self):return iter(self.of(use_main_plot=None).values())
+    def __reversed__(self):return reversed(self.of(use_main_plot=None).values())
+    def __contains__(self, item):return item in self.of(use_main_plot=None).keys()
+    def items(self, key_filter=lambda x:True):return [(x, y) for x,y in self.of(use_main_plot=None).items() if key_filter(x)]
+    def keys(self, key_filter=lambda x:True):return [x for x in self.of(use_main_plot=None).keys() if key_filter(x)]
+    def values(self, key_filter=lambda x:True):return [self[x] for x in self.of(use_main_plot=None).keys() if key_filter(x)]
+    def of(self, use_main_plot=True, key_filter=lambda x:True):
+        if use_main_plot is None:
+            total_items = {
+                **self.kwargs,
+                **self.subplot_kwargs,
+            }
+            return {x:y for x,y in total_items.items() if key_filter(x)}
+        elif use_main_plot:
+            return {x:y for x,y in self.kwargs.items() if key_filter(x)}
+        else:
+            return {x:y for x,y in self.subplot_kwargs.items() if key_filter(x)}
     @property
     def to_json(self):
         import json
-        return json.dumps(self.total_items)
+        return json.dumps(self.of(use_main_plot=None))
     @staticmethod
     def from_json(json_string):
         import json
@@ -224,5 +233,3 @@ class pltstyle(styleapplicator):
         for key,value in kwargs.items():
             current[key] = value
         return current
-
-
